# pytest-check-links

pytest plugin that checks URLs for HTML-containing files.

Supported files:

- .html
- .md (TODO: select renderer)
- .ipynb (requires nbconvert)

Install:

    pip install pytest-check-links

Use:

    pytest --check-links mynotebook.ipynb


